@@ -7,10 +7,10 @@ from pathlib import Path
 from typing import List, Optional
 
 from hoppr_cyclonedx_models.cyclonedx_1_3 import (
-    CyclonedxSoftwareBillOfMaterialSpecification as Bom_1_3,
+    CyclonedxSoftwareBillOfMaterialSpecification as Bom_1_3,  # type: ignore
 )
 from hoppr_cyclonedx_models.cyclonedx_1_4 import (
-    CyclonedxSoftwareBillOfMaterialsStandard as Bom_1_4,
+    CyclonedxSoftwareBillOfMaterialsStandard as Bom_1_4,  # type: ignore
 )
 from typer import echo
 
