@@ -1,7 +1,7 @@
 """
 Collector plugin for docker images
 """
-import urllib
+from pathlib import Path
 from typing import Any, Dict, Optional
 
 from packageurl import PackageURL  # type: ignore
@@ -13,6 +13,19 @@ from hoppr.context import Context
 from hoppr.result import Result
 
 
+def _artifact_string(purl):
+    artifact_string = purl.name
+    if purl.version is not None:
+        artifact_string += f"-{purl.version}"
+
+    # Limiting to an architecture using --archlist finds all compatible architectures,
+    # not just the specified one, so . . .
+    if "arch" in purl.qualifiers:
+        artifact_string += f"*{purl.qualifiers.get('arch')}"
+
+    return artifact_string
+
+
 class CollectYumPlugin(CollectorPlugin):
     """
     Collector plugin for yum images
@@ -38,10 +51,9 @@ class CollectYumPlugin(CollectorPlugin):
 
         purl = PackageURL.from_string(comp.purl)
 
-        file_name = urllib.parse.unquote(purl.name)
-        target_dir = self.directory_for(purl.type, repo_url, subdir=f"{purl.namespace}")
+        artifact = _artifact_string(purl)
 
-        self.get_logger().info(f"Copying yum package from {purl} to {target_dir}")
+        self.get_logger().info(f"Copying yum package from {purl}")
 
         command = [
             self.required_commands[0],
@@ -49,12 +61,12 @@ class CollectYumPlugin(CollectorPlugin):
             "--disableexcludes=all",
             "--downloadonly",
             "--urls",
-            file_name,
+            artifact,
         ]
 
         result = self.run_command(command)
         if result.returncode != 0:
-            msg = f"Yum failed to copy package to {target_dir}, return_code={result.returncode}"
+            msg = f"{self.required_commands[0]} failed to locate package for {purl}, return_code={result.returncode}"
             self.get_logger().error(msg)
 
             return Result.retry(msg)
@@ -71,13 +83,17 @@ class CollectYumPlugin(CollectorPlugin):
             self.get_logger().error(msg)
             return Result.fail(msg)
 
+        found_url_path = Path(found_url)
+        subdir = "/".join(found_url_path.parts[len(Path(repo_url).parts) : -1])
+        target_dir = self.directory_for(purl.type, repo_url, subdir=subdir)
+
         command = [
             self.required_commands[0],
             "-q",
             "--disableexcludes=all",
             "--downloadonly",
             f"--destdir={target_dir}",
-            file_name,
+            artifact,
         ]
 
         result = self.run_command(command, [])
