@@ -6,7 +6,7 @@ from pathlib import Path
 from platform import python_version
 from typing import List
 
-from typer import Option, Typer, echo
+from typer import Argument, Option, Typer, echo  # pylint: disable=unused-import
 
 from hoppr import __version__
 from hoppr.configs.credentials import Credentials
@@ -19,14 +19,22 @@ app = Typer()
 
 @app.command()
 def bundle(
-    manifest_file: Path,
-    auth_config_file: Path = Option(
-        None,
-        help="Specify authorization config for services",
-        envvar="HOPPR_AUTH_CONFIG",
+    manifest_file: Path = Argument(
+        "manifest.yml",
+        help="Path to manifest file file.  Default is manifest.yml in your local directory.",
+        expose_value=True,
     ),
-    transfer_config_file: Path = Option(
-        ...,
+    credentials_file: Path = Option(
+        None,
+        "-c",
+        "--credentials",
+        help="Specify credentials config for services",
+        envvar="HOPPR_CREDS_CONFIG",
+    ),
+    transfer_file: Path = Option(
+        "transfer.yml",
+        "-t",
+        "--transfer",
         help="Specify transfer config",
         envvar="HOPPR_TRANSFER_CONFIG",
     ),
@@ -35,14 +43,15 @@ def bundle(
     Run the stages specified in the transfer config file on the
     content specified in the manifest
     """
-    metadata_files = [manifest_file, transfer_config_file]
+    metadata_files = [manifest_file, transfer_file]
 
-    if auth_config_file is not None:
-        Credentials.load_file(auth_config_file)
-        metadata_files.append(auth_config_file)
+    if credentials_file is not None:
+        Credentials.load_file(credentials_file)
+        metadata_files.append(credentials_file)
 
     manifest = Manifest.load_file(manifest_file)
-    transfer = Transfer.load_file(transfer_config_file)
+
+    transfer = Transfer.load_file(transfer_file)
 
     processor = HopprProcessor(transfer, manifest)
     processor.metadata_files = metadata_files
@@ -66,6 +75,8 @@ def validate(
     input_files: List[Path],
     credentials_config_file: Path = Option(
         None,
+        "-c",
+        "--credentials",
         help="Specify authorization config for services",
         envvar="HOPPR_CREDS_CONFIG",
     ),
